# Credits

This package mixes two forks of https://github.com/audreyr/cookiecutter-pypackage/ by Audrey Roy Greenfeld:

- https://package-helper-2.readthedocs.io
- https://github.com/fpgmaas/cookiecutter-poetry

## Development Lead

- Fabien Mathieu <loufab@gmail.com>

## Contributors

- François Durand (PH2 and feedback).
